;;; Copyright 2014 Handi Chandra Putra
;;; Eco-Industrial Urban Evolution Model
extensions [ array ]
__includes ["_landmarket.nls"]

breed [ firms firm ]
breed [ workers worker ]
breed [ waters water]

firms-own [
  firm_type         ;; 0- 1-
  workers_req       ;; 0-lo 1-md 2-hi
  water_req         ;; 0-lo 1-md 2-hi
  hiwaste_req       ;; 0-lo 1-md 2-hi
  
  waste_treatment?  ;; 0-NO/LO 1-YES/HI
  waste_rate        ;; 0-lo 1-hi
  hiwaste_rate      ;; 0-lo 1-hi
  
  utility
  
;;;; DOUBLE AUCTION MARKET ;;;;;;
  role
  traded?
  MortgagePayment
  seller_askp0      ;; ask price at the initial state (higher or lower based on moving away, profit, affordability, etc)
  seller_cost
  seller_type       ;; 0 represpents non seller and sell for profit, they do not care whether they can their home or not; 1 means sell for move, they might lower price a little bit in later years, 2 means they want to sell houses as soon as possible, they will sell house even under their home value
  
  MaxLandPrice
  downpay
  person_land
  best_land
  candidatelands
  search_time
  buyer_value
  annual_fee
  ]

workers-own [
  utilityw
  
  ;;;; DOUBLE AUCTION MARKET ;;;;;;
  role
  traded?
  MortgagePayment
  seller_askp0      ;; ask price at the initial state (higher or lower based on moving away, profit, affordability, etc)
  seller_cost
  seller_type       ;; 0 represpents non seller and sell for profit, they do not care whether they can their home or not; 1 means sell for move, they might lower price a little bit in later years, 2 means they want to sell houses as soon as possible, they will sell house even under their home value

  MaxLandPrice
  downpay
  person_land
  best_land
  candidatelands
  search_time
  buyer_value
  annual_fee
  ]

patches-own [ 
  rentprice         ;; double auction market or normal mechanism
  wasteamount       ;; low waste amount - pollution
  hiwasteamount     ;; hi waste amount - pollution
  wateramount       ;; water resources available
  sddistance        ;; distance buffer
  transportmode     ;; 1|0.75|0.5|0.25 slowest to fastest transport region
  is-water-well?

;;;; DOUBLE AUCTION MARKET ;;;;;;
  visited?
  onmarket?
  land_value_atbuy
  lst_fees
  lst_duration
  property_tax
  downpayment
  influenced?
  land_person
  land_value
  ]

globals [
  counter view-mode ratelist workers-per-firm 
  transactionTotal transactionNum transactionPrice
  
  buyers sellers traders
  
  bestBid          ;; current best Bid
  bestBidID        ;; buyer with current best bid
  bid?             ;; bid available?
  bestAsk          ;; current best Ask
  bestAskID        ;; seller with current best ask
  ask?             ;; ask available?
  ]

to setup
  ca
  reset-ticks
  set view-mode "waters"
  set ratelist [ 2.5 5 7.5]
  
  setup-patches
  setup-waterwells
  setup-firms

  update-view

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; landscape layer
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to setup-patches
  ask patches
  [ set rentprice 10
    set wasteamount 10
    set hiwasteamount 10
    set wateramount 10
    set is-water-well? false
    set land_value Initial-LandValue
    land-reset-params
  ]
end

to setup-waterwells
  create-waters water-wells
  ask waters
  [ set color white
    move-to one-of patches with [ not any? turtles-here ]
    ask patch-here
    [ set pcolor blue
      set is-water-well? true
      set wateramount 100
    ]
  ]
  increase-water-natural
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; firms layer
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to setup-firms
  set workers-per-firm ((item (random 3) ratelist) * 10)
  create-firms 1
  ask firms
  [ init-firms-param
    ifelse (sample-random?) [ evaluate-firm-random ] [ evaluate-firm ]
    increase-waste waste_rate
    increase-hiwaste hiwaste_rate
    decrease-water water_req
    decrease-hiwaste hiwaste_req
    
  ]
  ask patches [ set sddistance min [ distance myself ] of firms ]
end

to init-firms-param
  set shape "factory"
  set size 3
  agent-reset-params

  set water_req (item (random 3) ratelist)
  set hiwaste_req (item (random 3) ratelist)
  set workers_req workers-per-firm
  
  set firm_type (random 2)
  if (firm_type = 0)  ;;; industrial symbiosis industries (e.g.coal-fired plants, cement plants, gypsum wall board manufacturers)
  [ set waste_treatment? 1
    set color green ;; waste treatment
    set waste_rate (item 0 ratelist)
    set hiwaste_rate (item 2 ratelist)
  ]
  if (firm_type = 1)  ;;; non-industrial symbiosis industries (e.g. semiconductor, bottled beverages)
  [ set waste_treatment? 0
    set color red ;; no waste treatment
    set waste_rate (item 2 ratelist)
    set hiwaste_rate (item 0 ratelist)
  ]
end

to setup-workers
  create-workers 5
  ask workers
  [ set shape "person"
    set size 2
    set color yellow
    let radius 10
    setxy ( ( radius / 2 ) - random-float ( radius * 1.0 ) ) ( ( radius / 2 ) - random-float ( radius * 1.0 ) )
    increase-price 5
    agent-reset-params
    ifelse (sample-random?) [evaluate-workers-random] [evaluate-workers]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  ask patches
  [ if (scenario-w_transportera = "Slow Transport") [ set transportmode item 2 ratelist ]
    if (scenario-w_transportera = "Hi-speed") [ set transportmode item 0 ratelist ]
  ]
  
  locate-workers
  if (counter > workers-per-firm)
  [ locate-firms
    set counter 0
    set workers-per-firm ((item (random 3) ratelist) * 100)
  ]
  
  if (ticks mod 1 = 0) [ increase-water-natural ]
  if (ticks mod 50 = 0) 
  [ decrease-water-natural
    decrease-waste-natural 
  ]
  
  if count (workers) >= 20 [ kill-workers ]
  if count (firms) >= max-firms [ kill-firms ]
  
  update-view
  do-plots
  tick
;  if ticks = 500 [stop]
end
  
to locate-workers
  set counter (counter + workers-per-step)
  create-workers workers-per-step
  [ set shape "person"
    set size 2
    set color yellow
    increase-price 5
    ifelse (sample-random?) [evaluate-workers-random] [evaluate-workers]
    agent-reset-params
  ]
end

to-report patch-utility-for-workers
;  report ( ( 1 / (sddistance + 0.1) ) ^ ( 1 - workers-quality-priority ) ) * ( wateramount ^ ( 1 + workers-quality-priority) )    ;; distance vs quality
  let $utility 0
  ;; Commuting Time
  if (scenario-w_commutetime)
  [ set $utility ($utility + ( ( 1 / ((sddistance * transportmode) + 0.1) ) ^ ( 1 ))) ]
  
  ;; Pollution
  if (scenario-w_pollution)
  [ set $utility ($utility + (100 - wasteamount) + (100 - hiwasteamount)) ]  ;; waste has a negative direction
  
  report $utility
end

to-report patch-utility-for-firms
  let $utility 0
  
  ;; sharing worker pool -- tend to clustered
  if (scenario-f_workerpool)
  [ set $utility ($utility + ( ( 1 / (sddistance + 0.1) ) ^ ( 1 ))) ]
  
  ;; Water Availability
  if (scenario-f_water)
  [ set $utility ($utility + wateramount) ]
  
  ;; High value waste Availability
  if (scenario-f_hiwaste)
  [ set $utility ($utility + hiwasteamount) ]

  report $utility
end

to kill-workers
  repeat ( death-rate)
  [ ;always kill the person that's been around the longest
    ask min-one-of workers [who] [ decrease-price 5 die ]
  ]
end

to kill-firms
  ask min-one-of firms [who] [ die ]
  ask patches [ set sddistance min [distance myself + .01] of firms ]
end

to locate-firms
  let empty-patches patches with [ not any? turtles-here ]

  if any? empty-patches
  [ ask one-of empty-patches
    [ sprout-firms 1
      [ init-firms-param
        ifelse (sample-random?) [ evaluate-firm-random ] [ evaluate-firm ]
        increase-waste waste_rate
        increase-hiwaste hiwaste_rate
        decrease-water water_req
        decrease-hiwaste hiwaste_req
      ]
    ]
    ask patches
      [ set sddistance min [distance myself + .01] of firms ]
  ]
end
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;; evaluating the whole world ;;;;;;;;;;;;;;;;;;;;;;;;;
to evaluate-workers
  let avail-patches patches with [not any? turtles-here ]
  if (not any? avail-patches) [ stop ]
  set candidatelands max-n-of number-of-tests avail-patches [ patch-utility-for-workers ]
  if (double-auction?) [ process-market ]
  let best-candidate max-one-of candidatelands [ patch-utility-for-workers ]
  move-to best-candidate
  set utilityw [ patch-utility-for-workers ] of best-candidate
end

to evaluate-firm
  let avail-patches patches with [not any? turtles-here ]
  if (not any? avail-patches) [ stop ]
  set candidatelands max-n-of number-of-tests avail-patches [ patch-utility-for-firms ]
  if (double-auction?) [ process-market ]
  let best-candidate max-one-of candidatelands [ patch-utility-for-firms ]
  move-to best-candidate
  set utility [ patch-utility-for-firms ] of best-candidate
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;; evaluate certain number of patches taken at random ;;;;;;;;;;;;;;;;;

to evaluate-workers-random
  set candidatelands n-of number-of-tests patches with [not any? turtles-here ]
  if (not any? candidatelands) [ stop ]
  if (double-auction?) [ process-market ]
  let best-candidate max-one-of candidatelands [ patch-utility-for-workers ]
  move-to best-candidate
  set utilityw [ patch-utility-for-workers ] of best-candidate
end

to evaluate-firm-random
  
  set candidatelands n-of number-of-tests patches with [ not any? turtles-here ]
  if (not any? candidatelands) [stop]
  if (double-auction?) [ process-market ]
  let best-candidate max-one-of candidatelands [patch-utility-for-firms]
  move-to best-candidate
  set utility [ patch-utility-for-firms ] of best-candidate
end

to increase-water-natural
  ask waters
  [ ask patch-here 
    [ set wateramount (wateramount + nature-rate) 
      if (wateramount > 100) [ set wateramount 100 ]
    ]
  ]
  diffuse wateramount 0.8
end

to decrease-water-natural
  ask patches with [wateramount > 20] 
  [ set wateramount (wateramount - nature-rate) 
    if (wateramount < 10) [ set wateramount 10 ]
  ]
end

to decrease-waste-natural
  ask patches with [wasteamount > 10 AND (count firms-here) = 0] 
  [ set wasteamount (wasteamount - nature-rate) 
    if (wasteamount < 10) [ set wasteamount 10 ]
  ]
  diffuse wasteamount 0.8
end

to increase-price [ #pricerate ]
  ask patch-here [ set rentprice (rentprice + #pricerate) ]
  ask patches in-radius 1 [ set rentprice (rentprice + #pricerate - 0.01) ]
  ask patches in-radius 2 [ set rentprice (rentprice + #pricerate - 0.02) ]
  ask patches in-radius 3 [ set rentprice (rentprice + #pricerate - 0.03) ]
  ask patches in-radius 4 [ set rentprice (rentprice + #pricerate - 0.04) ]
  ask patches in-radius 5 [ set rentprice (rentprice + #pricerate - 0.05) ]
  ask patches in-radius 6 [ set rentprice (rentprice + #pricerate - 0.06) ]
  ask patches in-radius 7 [ set rentprice (rentprice + #pricerate - 0.07) ]
  ask patches in-radius 8 [ set rentprice (rentprice + #pricerate - 0.08) ]
  ask patches in-radius 9 [ set rentprice (rentprice + #pricerate - 0.09) 
    if (rentprice > 100) [ set rentprice 100 ] ]
end
  
to decrease-price [ #pricerate ]
  ask patch-here [ set rentprice (rentprice - #pricerate) ]
  ask patches in-radius 1 [ set rentprice (rentprice - #pricerate - 0.04) ]
  ask patches in-radius 2 [ set rentprice (rentprice - #pricerate - 0.03) ]
  ask patches in-radius 3 [ set rentprice (rentprice - #pricerate - 0.02) ]
  ask patches in-radius 4 [ set rentprice (rentprice - #pricerate - 0.01)
    if (rentprice < 10) [ set rentprice 10 ]] 
end

to increase-water [ #waterrate ]
  ask patch-here [ set wateramount (wateramount + #waterrate) ]
  ask patches in-radius 1 [ set wateramount (wateramount + #waterrate - 0.01) ]
  ask patches in-radius 2 [ set wateramount (wateramount + #waterrate - 0.02) ]
  ask patches in-radius 3 [ set wateramount (wateramount + #waterrate - 0.03) ]
  ask patches in-radius 4 [ set wateramount (wateramount + #waterrate - 0.04) ]
  ask patches in-radius 5 [ set wateramount (wateramount + #waterrate - 0.05) ]
  ask patches in-radius 6 [ set wateramount (wateramount + #waterrate - 0.06) ]
  ask patches in-radius 7 [ set wateramount (wateramount + #waterrate - 0.07) ]
  ask patches in-radius 8 [ set wateramount (wateramount + #waterrate - 0.08) ]
  ask patches in-radius 9 [ set wateramount (wateramount + #waterrate - 0.09) 
    if (wateramount > 100) [ set wateramount 100 ] ]
end
  
to decrease-water [ #waterrate ]
  ask patch-here [ set wateramount (wateramount - #waterrate) ]
  ask patches in-radius 1 [ set wateramount (wateramount - #waterrate - 0.04) ]
  ask patches in-radius 2 [ set wateramount (wateramount - #waterrate - 0.03) ]
  ask patches in-radius 3 [ set wateramount (wateramount - #waterrate - 0.02) ]
  ask patches in-radius 4 [ set wateramount (wateramount - #waterrate - 0.01)
    if (wateramount < 10) [ set wateramount 10 ]] 
end

to increase-waste [ #wasterate ]
  ask patch-here [ set wasteamount (wasteamount + #wasterate) ]
  ask patches in-radius 1 [ set wasteamount (wasteamount + #wasterate - 0.01) ]
  ask patches in-radius 2 [ set wasteamount (wasteamount + #wasterate - 0.05) ]
  ask patches in-radius 3 [ set wasteamount (wasteamount + #wasterate - 0.1) ]
  ask patches in-radius 4 [ set wasteamount (wasteamount + #wasterate - 0.15) ]
  ask patches in-radius 5 [ set wasteamount (wasteamount + #wasterate - 0.2) ]
  ask patches in-radius 6 [ set wasteamount (wasteamount + #wasterate - 0.25) ]
  ask patches in-radius 7 [ set wasteamount (wasteamount + #wasterate - 0.3) ]
  ask patches in-radius 8 [ set wasteamount (wasteamount + #wasterate - 0.35) ]
  ask patches in-radius 9 [ set wasteamount (wasteamount + #wasterate - 0.4) 
    if (wasteamount > 100) [ set wasteamount 100 ] ]
end
  
to decrease-waste [ #wasterate ]
  ask patch-here [ set wasteamount (wasteamount - #wasterate) ]
  ask patches in-radius 1 [ set wasteamount (wasteamount - #wasterate - 0.04) if (wasteamount < 10) [ set wasteamount 10 ]]
  ask patches in-radius 2 [ set wasteamount (wasteamount - #wasterate - 0.03) if (wasteamount < 10) [ set wasteamount 10 ]]
  ask patches in-radius 3 [ set wasteamount (wasteamount - #wasterate - 0.02) if (wasteamount < 10) [ set wasteamount 10 ]]
  ask patches in-radius 4 [ set wasteamount (wasteamount - #wasterate - 0.01) if (wasteamount < 10) [ set wasteamount 10 ]]
end

to increase-hiwaste [ #wasterate ]
  ask patch-here [ set hiwasteamount (hiwasteamount + #wasterate) ]
  ask patches in-radius 1 [ set hiwasteamount (hiwasteamount + #wasterate - 0.01) ]
  ask patches in-radius 2 [ set hiwasteamount (hiwasteamount + #wasterate - 0.05) ]
  ask patches in-radius 3 [ set hiwasteamount (hiwasteamount + #wasterate - 0.1) ]
  ask patches in-radius 4 [ set hiwasteamount (hiwasteamount + #wasterate - 0.15) ]
  ask patches in-radius 5 [ set hiwasteamount (hiwasteamount + #wasterate - 0.2) ]
  ask patches in-radius 6 [ set hiwasteamount (hiwasteamount + #wasterate - 0.25) ]
  ask patches in-radius 7 [ set hiwasteamount (hiwasteamount + #wasterate - 0.3) ]
  ask patches in-radius 8 [ set hiwasteamount (hiwasteamount + #wasterate - 0.35) ]
  ask patches in-radius 9 [ set hiwasteamount (hiwasteamount + #wasterate - 0.4) 
    if (hiwasteamount > 100) [ set hiwasteamount 100 ] ]
end
  
to decrease-hiwaste [ #wasterate ]
  ask patch-here [ set hiwasteamount (hiwasteamount - #wasterate) ]
  ask patches in-radius 1 [ set hiwasteamount (hiwasteamount - #wasterate - 0.04) if (hiwasteamount < 10) [ set hiwasteamount 10 ]]
  ask patches in-radius 2 [ set hiwasteamount (hiwasteamount - #wasterate - 0.03) if (hiwasteamount < 10) [ set hiwasteamount 10 ]]
  ask patches in-radius 3 [ set hiwasteamount (hiwasteamount - #wasterate - 0.02) if (hiwasteamount < 10) [ set hiwasteamount 10 ]]
  ask patches in-radius 4 [ set hiwasteamount (hiwasteamount - #wasterate - 0.01) if (hiwasteamount < 10) [ set hiwasteamount 10 ]]
end

to update-view
  ask patches [ update-patch-color ]
end

to update-patch-color
  ;; the particular constants we use to scale the colors in the display
  ;; are mainly chosen for visual appeal
  ifelse view-mode = "rentprice"
  [ set pcolor scale-color yellow rentprice 0 100
  ][
  ifelse view-mode = "distance"
  [ set pcolor scale-color blue sddistance  ( 0.45 * ( max-pxcor * 1.414 ) ) ( 0.05 * ( max-pxcor * 1.414 ) )
  ][
  ifelse view-mode = "waters"
  [ set pcolor scale-color blue wateramount  0 100
  ][
  ifelse view-mode = "hiwasteamount"
  [ set pcolor scale-color green hiwasteamount  0 100
  ][
  if view-mode = "wasteamount"
  [ set pcolor scale-color red wasteamount 0 100
  ]
  ]]]]
end

to do-plots
  let wtotal 0
  let step 0
  let wtime 0
  
  set-current-plot "Travel Distance"
  set wtotal 0
  set wtime 0
  set-current-plot-pen "workers"
  plot median [ min [distance myself] of firms ] of workers
end
@#$#@#$#@
GRAPHICS-WINDOW
417
15
932
551
50
50
5.0
1
10
1
1
1
0
1
1
1
-50
50
-50
50
0
0
1
ticks
30.0

BUTTON
77
26
140
59
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
147
27
210
60
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
223
29
300
62
go-once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
24
79
89
112
view price
set view-mode \"rentprice\"\nupdate-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
91
79
154
112
view dist
set view-mode \"distance\"\nupdate-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
25
187
173
220
number-of-tests
number-of-tests
10
500
100
10
1
NIL
HORIZONTAL

SLIDER
24
224
172
257
max-firms
max-firms
0
100
100
1
1
NIL
HORIZONTAL

SLIDER
24
264
172
297
death-rate
death-rate
0
15
3
1
1
NIL
HORIZONTAL

SLIDER
24
306
172
339
workers-per-step
workers-per-step
0
15
4
1
1
NIL
HORIZONTAL

MONITOR
958
26
1025
71
# of firms
count firms
17
1
11

MONITOR
957
77
1025
122
population
count workers
17
1
11

BUTTON
156
79
229
112
view waste
set view-mode \"wasteamount\"\nupdate-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
24
341
172
374
water-wells
water-wells
0
30
30
1
1
NIL
HORIZONTAL

PLOT
1037
21
1237
171
Travel Distance
Time
# cells
0.0
100.0
0.0
20.0
true
false
"" ""
PENS
"workers" 1.0 0 -14730904 true "" ""

BUTTON
314
79
392
112
view waters
set view-mode \"waters\"\nupdate-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
209
202
391
235
scenario-f_workerpool
scenario-f_workerpool
0
1
-1000

SWITCH
209
169
391
202
scenario-f_water
scenario-f_water
0
1
-1000

SWITCH
206
346
392
379
scenario-w_commutetime
scenario-w_commutetime
0
1
-1000

TEXTBOX
206
143
402
162
FIRM LOCATION SCENARIOS
14
15.0
1

TEXTBOX
194
281
417
299
WORKER LOCATION SCENARIOS
14
15.0
1

SWITCH
206
378
392
411
scenario-w_pollution
scenario-w_pollution
0
1
-1000

SLIDER
23
380
173
413
nature-rate
nature-rate
0
10
7.5
0.5
1
NIL
HORIZONTAL

SWITCH
209
234
391
267
scenario-f_hiwaste
scenario-f_hiwaste
0
1
-1000

BUTTON
231
79
312
112
view hiwaste
set view-mode \"hiwasteamount\"\nupdate-view
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
206
301
392
346
scenario-w_transportera
scenario-w_transportera
"Slow Transport" "High-speed"
0

PLOT
203
471
403
621
Demand-Supply
Quantity
Price
0.0
40.0
0.0
40.0
true
false
"" ""
PENS
"supply-pen" 1.0 0 -13345367 true "" ""
"demand-pen" 1.0 0 -2674135 true "" ""

SLIDER
24
429
172
462
Mortgage-Interest
Mortgage-Interest
0
1
0.12
0.01
1
NIL
HORIZONTAL

SLIDER
24
463
172
496
PropertyTax-Rate
PropertyTax-Rate
0
1
0.02
0.01
1
NIL
HORIZONTAL

SWITCH
24
151
174
184
sample-random?
sample-random?
0
1
-1000

PLOT
1037
186
1237
336
Land Value
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "if (sum [land_value] of patches != 0)\n[plot mean [land_value] of patches]"

SLIDER
22
501
174
534
Initial-LandValue
Initial-LandValue
0
100000
50000
10000
1
NIL
HORIZONTAL

SWITCH
1038
348
1205
381
double-auction?
double-auction?
1
1
-1000

MONITOR
945
129
1026
174
Med Distance
precision (median [ min [distance myself] of firms ] of workers) 2
17
1
11

MONITOR
943
191
1024
236
Rent Price
precision (mean [rentprice] of patches with [any? turtles-here]) 2
17
1
11

@#$#@#$#@
## WHAT IS IT?

### AGENTS ###

#### Households ####
  - Preferences (Employment sector, Neighbours, Services, Environment)
  - Visibility

#### Firms ####
  - Sector (Employment, Natural Resources)
  - Visibility

## HOW IT WORKS



## HOW TO USE IT



## THINGS TO NOTICE



## THINGS TO TRY


## EXTENDING THE MODEL



## NETLOGO FEATURES



## CREDITS AND REFERENCES

This model was loosely based on a model originally written by William Rand and Derek Robinson as prt of the Sluce Project at the University of Michigan (http://www.cscs.umich.edu/sluce).  For more about the original model (SOME) that was the basis for this model, please see:

Brown D.G., Robinson D.T., Nassauer J.I., An L., Page S.E., Low B., Rand W., Zellner M., and R. Riolo (In Press) "Exurbia from the Bottom-Up: Agent-Based Modeling and Empirical Requirements." Geoforum.

This model was developed during the Sprawl/Swarm Class at Illinois Institute of Technology in Fall 2006 under the supervision of Sarah Dunn and Martin Felsen, by the following group of students: Danil Nagy and Bridget Dodd.  See http://www.sprawlcity.us/ for more details.

Further modifications and refinements were made by members of the Center for Connected Learning and Computer-Based Modeling before releasing it as an Urban Suite model.

The Urban Suite models were developed as part of the Procedural Modeling of Cities project, under the sponsorship of NSF ITR award 0326542, Electronic Arts & Maxis.

Please see the project web site ( http://ccl.northwestern.edu/cities/ ) for more information.


## HOW TO CITE

If you mention this model in a publication, we ask that you include these citations for the model itself and for the NetLogo software:

* Felsen, M. and Wilensky, U. (2007).  NetLogo Urban Suite - Economic Disparity model.  http://ccl.northwestern.edu/netlogo/models/UrbanSuite-EconomicDisparity.  Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
* Wilensky, U. (1999). NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

## COPYRIGHT AND LICENSE

Copyright 2007 Uri Wilensky.

![CC BY-NC-SA 3.0](http://i.creativecommons.org/l/by-nc-sa/3.0/88x31.png)

This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 License.  To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.

Commercial licenses are also available. To inquire about commercial licenses, please contact Uri Wilensky at uri@northwestern.edu.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

factory
false
0
Rectangle -7500403 true true 76 194 285 270
Rectangle -7500403 true true 36 95 59 231
Rectangle -16777216 true false 90 210 270 240
Line -7500403 true 90 195 90 255
Line -7500403 true 120 195 120 255
Line -7500403 true 150 195 150 240
Line -7500403 true 180 195 180 255
Line -7500403 true 210 210 210 240
Line -7500403 true 240 210 240 240
Line -7500403 true 90 225 270 225
Circle -1 true false 37 73 32
Circle -1 true false 55 38 54
Circle -1 true false 96 21 42
Circle -1 true false 105 40 32
Circle -1 true false 129 19 42
Rectangle -7500403 true true 14 228 78 270

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>count firms</metric>
    <metric>count workers</metric>
    <metric>count firms / count workers</metric>
    <metric>precision (median [ min [distance myself] of firms ] of workers) 2</metric>
    <metric>precision (mean [rentprice] of patches with [any? turtles-here]) 2</metric>
    <enumeratedValueSet variable="Initial-LandValue">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PropertyTax-Rate">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sample-random?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nature-rate">
      <value value="7.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mortgage-Interest">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="double-auction?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-firms">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="workers-per-step">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-tests">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="water-wells">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scenario-f_water">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scenario-f_workerpool">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scenario-f_hiwaste">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scenario-w_transportera">
      <value value="&quot;High-speed&quot;"/>
      <value value="&quot;Slow Transport&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scenario-w_commutetime">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scenario-w_pollution">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
